@@ -80,6 +80,28 @@ async def get_ship_byName(shipname:str):
             return List
         else:
             return None
+    except Exception:
+        logger.error(traceback.format_exc())
+        return None
+    
+async def get_AccountIdByName(server:str,name:str):
+    try:
+        url = 'https://api.wows.linxun.link/public/wows/account/search/user'
+        params = {
+            "server": server,
+            "userName": name
+        }
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        async with httpx.AsyncClient(headers=headers) as client:
+            resp = await client.get(url, params=params, timeout=20)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            result = resp.json()
+        if result['code'] == 200 and result['data']:
+            return result['data']['accountId']
+        elif result['code'] == 404:
+            return 404
+        else:
+            return None
     except Exception:
         logger.error(traceback.format_exc())
         return None
\ No newline at end of file
