@@ -6,11 +6,12 @@ import jinja2
 import re
 from pathlib import Path
 from .data_source import servers,set_infoparams
-from .utils import match_keywords
+from .utils import match_keywords,encode_gzip
+from .publicAPI import get_AccountIdByName
 from nonebot_plugin_htmlrender import html_to_pic
 from nonebot import get_driver
 from nonebot.log import logger
-
+import json
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
@@ -22,25 +23,7 @@ headers = {
     'Authorization': get_driver().config.api_token
 }
   
-async def get_AccountIdByName(server:str,name:str):
-    try:
-        url = 'https://api.wows.linxun.link/public/wows/account/search/user'
-        params = {
-            "server": server,
-            "userName": name
-        }
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
-        async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
-            result = resp.json()
-        if result['data']:
-            return result['data']['accountId']
-        else:
-            return None
-    except Exception:
-        logger.error(traceback.format_exc())
-        return None
+
     
 
 async def get_AccountInfo(qqid,info):
@@ -49,7 +32,7 @@ async def get_AccountInfo(qqid,info):
         if isinstance(info,List):
             for i in info:
                 if i == 'me':
-                    url = 'https://api.wows.linxun.link/public/wows/account/user/info'
+                    url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                     params = {
                     "server": "QQ",
                     "accountId": str(qqid)
@@ -57,7 +40,7 @@ async def get_AccountInfo(qqid,info):
                     break
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link/public/wows/account/user/info'
+                    url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                     params = {
                     "server": "QQ",
                     "accountId": match.group(1)
@@ -67,14 +50,16 @@ async def get_AccountInfo(qqid,info):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))
-                    if param_accountid:
-                        url = 'https://api.wows.linxun.link/public/wows/account/user/info'
+                    if param_accountid and param_accountid != 404:
+                        url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                         params = {
                         "server": param_server,
                         "accountId": param_accountid
                         }
+                    elif param_accountid == 404:
+                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在，也有可能是网络波动，请稍后再试'
+                        return '发生了错误，有可能是网络波动，请稍后再试'
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
@@ -90,9 +75,13 @@ async def get_AccountInfo(qqid,info):
             result = resp.json()
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-info.html")
+            print(template)
             template_data = await set_infoparams(result['data'])
+            print(template)
             content = await template.render_async(template_data)
             return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 1000})
+        elif result['code'] == 403:
+            return f"{result['message']}\n请先绑定账号"
         elif result['code'] == 404:
             return f"{result['message']}"
         elif result['code'] == 500:
